import { ApiRequest } from '../ApiRequest';
import { Schema$CustomField } from './Account';
import { EntityType, Schema$EntityParams } from './Entity';
import { Schema$GetListParams } from './ListEntity';
/**
 * Events provide the ability to add additional structured or unstructured
 * information to an entity element. Events can be system calls (calls, SMS
 * messages, etc.) created by the user (notes, files). The events in the cards
 * are displayed alongside the to-dos, because do not have a responsible one and
 * are not attached to the date. Often events are used by widgets to add
 * additional information to a lead or contact, when it is not very convenient
 * to use additional fields. Events are very convenient to use as a log, because
 * they are always displayed in chronological order in the tape, and if your
 * information is tied to a date (chronology), then it is desirable to use
 * events.
 *
 * The method allows you to add new or update existing events.
 *
 * @link https://www.amocrm.com/developers/content/api/notes
 */
export declare class Note {
    apiRequest: ApiRequest;
    private url;
    constructor(apiRequest: ApiRequest);
    /**
     * Method for obtaining a list of notes with the possibility of filtering and
     * pagination. Restriction on data returned on one page (offset) - 500
     * entries.
     *
     * @param params
     * @param modified
     */
    list(params: Schema$NoteGetListParams, modified?: string): Promise<import("gaxios").GaxiosResponse<any>>;
    add(params: Schema$NoteAddParams[]): Promise<import("gaxios").GaxiosResponse<any>>;
    update(params: Schema$NoteUpdateParams[]): Promise<import("gaxios").GaxiosResponse<any>>;
}
interface Schema$NoteParams {
    /**
     * The date to which you want to complete the task. If the time is 23:59,
     * then "All day" will be displayed in the system interfaces instead of time.
     */
    complete_till_at?: number;
    /** Type of task (task types see here) */
    task_type?: NoteType | number;
    /** Note text */
    text?: string;
    /** Note completed or not */
    is_completed?: boolean;
    /**
     * Status of the Note (id of the sales phase, see Pipelines and stages of
     * sales) To transfer the Note to another pipeline, you need to set its status
     * from the desired pipeline
     */
    status_id?: number;
    /**
     * ID of the pipeline. It is indicated if id 142 or 143 statuses are
     * selected, because These statuses are not unique and are mandatory for all
     * digital pipelines.
     */
    pipeline_id?: number;
    /**
     * The unique identifier for the contact to contact the Note. You can pass
     * multiple id, listing them in an array separated by commas.
     */
    contacts_id?: number | number[];
    /** The unique identifier of the company to contact the Note  */
    company_id?: number;
    /** Inside this array is the contents of each filled additional field */
    custom_fields?: Schema$CustomField[];
    /**
     * Parameters for creating a call-type event. The params array is passed
     * instead of the text parameter.
     */
    params?: {};
}
export interface Schema$NoteAddParams extends Schema$NoteParams, Schema$EntityParams {
    /** id of the element, the event will be added to the card  */
    element_id: number;
    /** The type of the entity in which the event is added to the card.  */
    element_type: EntityType;
}
export interface Schema$CommonNoteAddParams extends Schema$NoteAddParams {
    note_type: NoteType.COMMON | NoteType.COMPANY_CREATED | NoteType.CONTACT_CREATED | NoteType.LEAD_CREATED | NoteType.LEAD_STATUS_CHANGED | NoteType.TASK_RESULT;
    /** Event text  */
    text: string;
}
export interface Schema$CallNoteAddParams extends Schema$NoteAddParams {
    /** The type of the event to add. */
    note_type: NoteType.CALL_IN | NoteType.CALL_OUT;
    params: {
        'UNIQ': string;
        'LINK': string;
        'PHONE': string;
        'DURATION': number;
        'SRC': string;
    };
}
export interface Schema$TextNoteAddParams extends Schema$NoteAddParams {
    note_type: NoteType.SMS_IN | NoteType.SMS_OUT | NoteType.SYSTEM;
    params: {
        /**
         * For the "system message" event type, the text is sent using the params
         * array, instead of the text parameter.
         */
        text: string;
    };
}
export interface Schema$NoteUpdateParams extends Schema$NoteParams, Schema$EntityParams {
    id: number;
    updated_at: number;
}
export interface Schema$NoteGetListParams extends Schema$GetListParams {
    /** contact/lead/company/task Retrieve data only for the specified entity */
    type: 'contact' | 'lead' | 'company' | 'task';
    /** The unique identifier of the entity element */
    element_id?: number;
    /** The unique identifier of the contact or lead. */
    note_type?: NoteType;
}
/**
 *  Types of events
 *
 * @link https://www.amocrm.com/developers/content/api/notes#note_types
 */
export declare enum NoteType {
    LEAD_CREATED = 1,
    CONTACT_CREATED = 2,
    LEAD_STATUS_CHANGED = 3,
    /** Normal note  */
    COMMON = 4,
    CALL_IN = 10,
    CALL_OUT = 11,
    COMPANY_CREATED = 12,
    TASK_RESULT = 13,
    SYSTEM = 25,
    SMS_IN = 102,
    SMS_OUT = 103
}
export {};
